import pandas as pd
import lxml.etree as et
import logging

prefix_map = {"g": "http://base.google.com/ns/1.0"}

def readOldXML(file, new_name):
    root = et.Element('offers')
    for event, elem in et.iterparse(file, strip_cdata = False):
        if elem.tag == "item":
            entry = {
                'id': "None",
                'url': "shumee.pl",
                'price': "None",
                'avail': "0",
                'stock': "None",
                'cat': "None",
                'name': "None",
                'images': [],
                'desc': "None",
                'attrs': {}
            }
            
            entry['id'] = elem.find('g:id', prefix_map).text
            
            entry['price'] = elem.find('g:price', prefix_map).text.split()[0]
            
            entry['stock'] = elem.find('g:availability', prefix_map).text
            if int(entry['stock']) > 0:
                entry['avail'] = '1'
            else:
                entry['avail'] = '0'
            
            if elem.find('g:product_width', prefix_map):
                entry['attrs']['width'] = elem.find('g:product_width', prefix_map).text
            if elem.find('g:product_length', prefix_map):    
                entry['attrs']['length'] = elem.find('g:product_length', prefix_map).text
            if elem.find('g:product_height', prefix_map):
                entry['attrs']['width'] = elem.find('g:product_height', prefix_map).text
            if elem.find('g:product_weight', prefix_map):
                entry['attrs']['weight'] = elem.find('g:product_weight', prefix_map).text

            entry['cat'] = elem.find('g:product_type', prefix_map).text
            
            entry['name'] = elem.find('g:title', prefix_map).text
            
            entry['images'].append(elem.find('g:image_link', prefix_map).text)
            for image in elem.findall('g:additional_image_link', prefix_map):
                entry['images'].append(image.text)
            
            entry['desc'] = elem.find('g:description', prefix_map).text
            
            entry['attrs']['Kod_producenta'] = elem.find('g:id', prefix_map).text
            try:
                entry['attrs']['EAN'] = elem.find('g:gtin', prefix_map).text
                entry['attrs']['Brand'] = elem.find('g:brand', prefix_map).text
            
            except AttrbiuteError:
                entry['attrs']['EAN'] = "Brak"
                entry['attrs']['Brand'] = "Brak"
            
            elem.clear()
            root = save(entry, root)
            logging.info('Successfully appended entry ' + str(entry['id']))
    xml_to_save = et.ElementTree(root)
    with open(new_name, 'wb') as f:
        xml_to_save.write(f, pretty_print=True, xml_declaration=True, method='xml', encoding='utf-8')
    

def save(entry, root):
    offer = et.SubElement(root, "o", id=str(entry['id']), url=str(entry['url']), price=str(entry['price']), avail=str(entry['avail']), stock=str(entry['stock']))
    
    category = et.SubElement(offer, "cat")
    category.text = et.CDATA(str(entry["cat"]))
    
    name = et.SubElement(offer, "name")
    name.text = et.CDATA(str(entry["name"]))
    
    desc = et.SubElement(offer, "desc")
    desc.text = et.CDATA(str(entry["desc"]))
    
    imgs = et.SubElement(offer, "imgs")
    if entry['images']:
        main = et.SubElement(imgs, "main", url=entry["images"][0])
        for image in entry["images"][1:]:
            i = et.SubElement(imgs, "i", url=str(image))
    
    attrs = et.SubElement(offer, "attrs")
    for key in entry["attrs"]:
        a = et.SubElement(attrs, "a", name=key)
        a.text = et.CDATA(str(entry["attrs"][key]))
    return root

def execute(old_name, new_name): 
    readOldXML(old_name, new_name)